%global momorel 3

# Do we want SELinux & Audit
%define WITH_SELINUX 1

# OpenSSH privilege separation requires a user & group ID
%define sshd_uid    74
%define sshd_gid    74

# Do we want to link against a static libcrypto? (1=yes 0=no)
%define static_libcrypto 0

# Do we want smartcard support (1=yes 0=no)
%define scard 0

# Build position-independent executables (requires toolchain support)?
%define pie 1

# Do we want kerberos5 support (1=yes 0=no)
%define kerberos5 1

# Do we want libedit support
%define libedit 1

# Do we want NSS tokens support
%define nss 1

# Whether or not /sbin/nologin exists.
%define nologin 1

# Add option to build without GTK2 for older platforms with only GTK+.
# Red Hat Linux <= 7.2 and Red Hat Advanced Server 2.1 are examples.
# rpm -ba|--rebuild --define 'no_gtk2 1'
%{?no_gtk2:%define gtk2 0}

# Options for static OpenSSL link:
# rpm -ba|--rebuild --define "static_openssl 1"
%{?static_openssl:%define static_libcrypto 1}

# Options for Smartcard support: (needs libsectok and openssl-engine)
# rpm -ba|--rebuild --define "smartcard 1"
%{?smartcard:%define scard 1}

# Is this a build for the rescue CD (without PAM, with MD5)? (1=yes 0=no)
%define rescue 0
%{?build_rescue:%define rescue 1}
%{?build_rescue:%define rescue_rel rescue}

# Turn off some stuff for resuce builds
%if %{rescue}
%define kerberos5 0
%define libedit 0
%endif

Summary: The OpenSSH implementation of SSH protocol versions 1 and 2
Name: openssh

### include local configuration
%{?include_specopt}
### default configurations
#  If you'd like to change these configurations, please copy them to
# ~/rpm/specopt/openssh.specopt and edit it.
%{?!with_lpk: %global with_lpk 1}

Version: 5.2p1
Release: %{momorel}m%{?dist}
URL: http://www.openssh.com/portable.html
Source0: ftp://ftp.openbsd.org/pub/OpenBSD/OpenSSH/portable/openssh-%{version}.tar.gz
NoSource: 0
#Source1: ftp://ftp.openbsd.org/pub/OpenBSD/OpenSSH/portable/openssh-%{version}.tar.gz.asc
# This package differs from the upstream OpenSSH tarball in that
# the ACSS cipher is removed by running openssh-nukeacss.sh in
# the unpacked source directory.
Source1: openssh-nukeacss.sh
Source2: sshd.pam
Source3: sshd.init
Patch0: openssh-5.2p1-redhat.patch
Patch2: openssh-5.1p1-skip-initial.patch
Patch3: openssh-3.8.1p1-krb5-config.patch
Patch4: openssh-5.2p1-vendor.patch
Patch12: openssh-5.2p1-selinux.patch
Patch13: openssh-5.1p1-mls.patch
Patch16: openssh-4.7p1-audit.patch
Patch17: openssh-4.3p2-cve-2007-3102.patch
Patch18: openssh-5.0p1-pam_selinux.patch
Patch22: openssh-3.9p1-askpass-keep-above.patch
Patch24: openssh-4.3p1-fromto-remote.patch
Patch27: openssh-5.1p1-log-in-chroot.patch
Patch30: openssh-4.0p1-exit-deadlock.patch
Patch35: openssh-5.1p1-askpass-progress.patch
Patch38: openssh-4.3p2-askpass-grab-info.patch
Patch39: openssh-4.3p2-no-v6only.patch
Patch44: openssh-4.3p2-allow-ip-opts.patch
Patch49: openssh-4.3p2-gssapi-canohost.patch
Patch51: openssh-5.2p1-nss-keys.patch
Patch54: openssh-5.1p1-gssapi-role.patch
Patch55: openssh-5.1p1-cloexec.patch
Patch62: openssh-5.1p1-scp-manpage.patch
#Patch63: openssh-5.1p1-bannerlen.patch
Patch100: openssh-lpk-5.2p1-0.3.10.patch

License: BSD
Group: Applications/Internet
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
%if %{nologin}
Requires: util-linux
%endif

Requires: initscripts >= 5.20

%if %{scard}
BuildRequires: sharutils
%endif
BuildRequires: autoconf, automake, openssl-devel, perl, zlib-devel
BuildRequires: audit-libs-devel
BuildRequires: util-linux, groff, man
BuildRequires: pam-devel
BuildRequires: tcp_wrappers-devel

%if %{kerberos5}
BuildRequires: krb5-devel
%endif

%if %{libedit}
BuildRequires: libedit-devel ncurses-devel
%endif

%if %{nss}
BuildRequires: nss-devel
%endif

%if %{WITH_SELINUX}
Requires: libselinux >= 1.27.7
BuildRequires: libselinux-devel >= 1.27.7
Requires: audit-libs >= 1.0.8
BuildRequires: audit-libs >= 1.0.8
%endif

%if %{with_lpk}
Requires: openldap
BuildRequires: openldap-devel
%endif

BuildRequires: xorg-x11-xauth

Obsoletes: openssh-keysign

%package clients
Summary: The OpenSSH client applications
Requires: openssh = %{version}-%{release}
Group: Applications/Internet

%package server
Summary: The OpenSSH server daemon
Group: System Environment/Daemons
Requires: openssh = %{version}-%{release}
Requires(post): chkconfig >= 0.9
Requires(pre): shadow-utils
Requires: pam >= 1.0.1-3
%if %{with_lpk}
Requires: openldap
%endif

%description
SSH (Secure SHell) is a program for logging into and executing
commands on a remote machine. SSH is intended to replace rlogin and
rsh, and to provide secure encrypted communications between two
untrusted hosts over an insecure network. X11 connections and
arbitrary TCP/IP ports can also be forwarded over the secure channel.

OpenSSH is OpenBSD's version of the last free version of SSH, bringing
it up to date in terms of security and features, as well as removing
all patented algorithms to separate libraries.

This package includes the core files necessary for both the OpenSSH
client and server. To make this package useful, you should also
install openssh-clients, openssh-server, or both.

%description clients
OpenSSH is a free version of SSH (Secure SHell), a program for logging
into and executing commands on a remote machine. This package includes
the clients necessary to make encrypted connections to SSH servers.
You'll also need to install the openssh package on OpenSSH clients.

%description server
OpenSSH is a free version of SSH (Secure SHell), a program for logging
into and executing commands on a remote machine. This package contains
the secure shell daemon (sshd). The sshd daemon allows SSH clients to
securely connect to your SSH server. You also need to have the openssh
package installed.

%prep
%setup -q
%patch0 -p1 -b .redhat
%patch2 -p1 -b .skip-initial
%patch3 -p1 -b .krb5-config
%patch4 -p1 -b .vendor

%if %{WITH_SELINUX}
#SELinux
%patch12 -p1 -b .selinux
%patch13 -p1 -b .mls
%patch16 -p1 -b .audit
%patch17 -p1 -b .inject-fix
%patch18 -p1 -b .pam_selinux
%endif

%patch22 -p1 -b .keep-above
%patch24 -p1 -b .fromto-remote
%patch27 -p1 -b .log-chroot
%patch30 -p1 -b .exit-deadlock
%patch35 -p1 -b .progress
%patch38 -p1 -b .grab-info
%patch39 -p1 -b .no-v6only
%patch44 -p1 -b .ip-opts
%patch49 -p1 -b .canohost
%patch51 -p1 -b .nss-keys
%patch54 -p1 -b .gssapi-role
%patch55 -p1 -b .cloexec
%patch62 -p1 -b .manpage
#%%patch63 -p1 -b .bannerlen

%if %{with_lpk}
%patch100 -p1
%endif

autoreconf

%build
CFLAGS="$RPM_OPT_FLAGS"; export CFLAGS
%if %{rescue}
CFLAGS="$CFLAGS -Os"
%endif
%if %{pie}
%ifarch s390 s390x sparc sparcv9 sparc64
CFLAGS="$CFLAGS -fPIE"
%else
CFLAGS="$CFLAGS -fpie"
%endif
export CFLAGS
LDFLAGS="$LDFLAGS -pie"; export LDFLAGS
%endif
%if %{kerberos5}
source /etc/profile.d/krb5-devel.sh
krb5_prefix=`krb5-config --prefix`
if test "$krb5_prefix" != "%{_prefix}" ; then
	CPPFLAGS="$CPPFLAGS -I${krb5_prefix}/include -I${krb5_prefix}/include/gssapi"; export CPPFLAGS
	CFLAGS="$CFLAGS -I${krb5_prefix}/include -I${krb5_prefix}/include/gssapi"
	LDFLAGS="$LDFLAGS -L${krb5_prefix}/%{_lib}"; export LDFLAGS
else
	krb5_prefix=
	CPPFLAGS="-I%{_includedir}/gssapi"; export CPPFLAGS
	CFLAGS="$CFLAGS -I%{_includedir}/gssapi"
fi
%endif

%configure \
	--sysconfdir=%{_sysconfdir}/ssh \
	--libexecdir=%{_libexecdir}/openssh \
	--datadir=%{_datadir}/openssh \
	--with-tcp-wrappers \
	--with-rsh=%{_bindir}/rsh \
	--with-default-path=/usr/local/bin:/bin:/usr/bin \
	--with-superuser-path=/usr/local/sbin:/usr/local/bin:/sbin:/bin:/usr/sbin:/usr/bin \
	--with-privsep-path=%{_var}/empty/sshd \
	--enable-vendor-patchlevel="FC-%{version}-%{release}" \
	--disable-strip \
	--without-zlib-version-check \
%if %{nss}
	--with-nss \
%endif
%if %{scard}
	--with-smartcard \
%endif
%if %{rescue}
	--without-pam \
%else
	--with-pam \
%endif
%if %{WITH_SELINUX}
	--with-selinux --with-linux-audit \
%endif
%if %{kerberos5}
	--with-kerberos5${krb5_prefix:+=${krb5_prefix}} \
%else
	--without-kerberos5 \
%endif
%if %{with_lpk}
	--with-ldap \
%endif
%if %{libedit}
	--with-libedit
%else
	--without-libedit
%endif

%if %{static_libcrypto}
perl -pi -e "s|-lcrypto|%{_libdir}/libcrypto.a|g" Makefile
%endif

make

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p -m755 $RPM_BUILD_ROOT%{_sysconfdir}/ssh
mkdir -p -m755 $RPM_BUILD_ROOT%{_libexecdir}/openssh
mkdir -p -m755 $RPM_BUILD_ROOT%{_var}/empty/sshd
make install DESTDIR=$RPM_BUILD_ROOT

install -d $RPM_BUILD_ROOT/etc/pam.d/
install -d $RPM_BUILD_ROOT/etc/init.d
install -d $RPM_BUILD_ROOT%{_libexecdir}/openssh
install -m644 %{SOURCE2} $RPM_BUILD_ROOT/etc/pam.d/sshd
install -m755 %{SOURCE3} $RPM_BUILD_ROOT/etc/init.d/sshd
install -m755 contrib/ssh-copy-id $RPM_BUILD_ROOT%{_bindir}/
install contrib/ssh-copy-id.1 $RPM_BUILD_ROOT%{_mandir}/man1/

%if ! %{scard}
	rm -f $RPM_BUILD_ROOT%{_datadir}/openssh/Ssh.bin
%endif

perl -pi -e "s|$RPM_BUILD_ROOT||g" $RPM_BUILD_ROOT%{_mandir}/man*/*

rm -f README.nss.nss-keys
%if ! %{nss}
rm -f README.nss
%endif
%clean
rm -rf $RPM_BUILD_ROOT

%triggerun server -- ssh-server
if [ "$1" != 0 -a -r /var/run/sshd.pid ] ; then
	touch /var/run/sshd.restart
fi

%triggerun server -- openssh-server < 2.5.0p1
# Count the number of HostKey and HostDsaKey statements we have.
gawk	'BEGIN {IGNORECASE=1}
	 /^hostkey/ || /^hostdsakey/ {sawhostkey = sawhostkey + 1}
	 END {exit sawhostkey}' /etc/ssh/sshd_config
# And if we only found one, we know the client was relying on the old default
# behavior, which loaded the the SSH2 DSA host key when HostDsaKey wasn't
# specified.  Now that HostKey is used for both SSH1 and SSH2 keys, specifying
# one nullifies the default, which would have loaded both.
if [ $? -eq 1 ] ; then
	echo HostKey /etc/ssh/ssh_host_rsa_key >> /etc/ssh/sshd_config
	echo HostKey /etc/ssh/ssh_host_dsa_key >> /etc/ssh/sshd_config
fi

%triggerpostun server -- ssh-server
if [ "$1" != 0 ] ; then
	/sbin/chkconfig --add sshd
	if test -f /var/run/sshd.restart ; then
		rm -f /var/run/sshd.restart
		/sbin/service sshd start > /dev/null 2>&1 || :
	fi
fi

%pre server
%if %{nologin}
/usr/sbin/useradd -c "Privilege-separated SSH" -u %{sshd_uid} \
	-s /sbin/nologin -r -d /var/empty/sshd sshd 2> /dev/null || :
%else
/usr/sbin/useradd -c "Privilege-separated SSH" -u %{sshd_uid} \
	-s /dev/null -r -d /var/empty/sshd sshd 2> /dev/null || :
%endif

%post server
/sbin/chkconfig --add sshd

%postun server
/sbin/service sshd condrestart > /dev/null 2>&1 || :

%preun server
if [ "$1" = 0 ]
then
	/sbin/service sshd stop > /dev/null 2>&1 || :
	/sbin/chkconfig --del sshd
fi

%files
%defattr(-,root,root)
%doc CREDITS ChangeLog INSTALL LICENCE OVERVIEW PROTOCOL* README* TODO WARNING*
%attr(0755,root,root) %dir %{_sysconfdir}/ssh
%attr(0600,root,root) %config(noreplace) %{_sysconfdir}/ssh/moduli
%if ! %{rescue}
%attr(0755,root,root) %{_bindir}/ssh-keygen
%attr(0644,root,root) %{_mandir}/man1/ssh-keygen.1*
%attr(0755,root,root) %dir %{_libexecdir}/openssh
%attr(4755,root,root) %{_libexecdir}/openssh/ssh-keysign
%attr(0644,root,root) %{_mandir}/man8/ssh-keysign.8*
%endif
%if %{scard}
%attr(0755,root,root) %dir %{_datadir}/openssh
%attr(0644,root,root) %{_datadir}/openssh/Ssh.bin
%endif

%files clients
%defattr(-,root,root)
%attr(0755,root,root) %{_bindir}/ssh
%attr(0644,root,root) %{_mandir}/man1/ssh.1*
%attr(0755,root,root) %{_bindir}/scp
%attr(0644,root,root) %{_mandir}/man1/scp.1*
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/ssh/ssh_config
%attr(0755,root,root) %{_bindir}/slogin
%attr(0644,root,root) %{_mandir}/man1/slogin.1*
%attr(0644,root,root) %{_mandir}/man5/ssh_config.5*
%if ! %{rescue}
%attr(2755,root,nobody) %{_bindir}/ssh-agent
%attr(0755,root,root) %{_bindir}/ssh-add
%attr(0755,root,root) %{_bindir}/ssh-keyscan
%attr(0755,root,root) %{_bindir}/sftp
%attr(0755,root,root) %{_bindir}/ssh-copy-id
%attr(0644,root,root) %{_mandir}/man1/ssh-agent.1*
%attr(0644,root,root) %{_mandir}/man1/ssh-add.1*
%attr(0644,root,root) %{_mandir}/man1/ssh-keyscan.1*
%attr(0644,root,root) %{_mandir}/man1/sftp.1*
%attr(0644,root,root) %{_mandir}/man1/ssh-copy-id.1*
%endif

%if ! %{rescue}
%files server
%defattr(-,root,root)
%dir %attr(0711,root,root) %{_var}/empty/sshd
%attr(0755,root,root) %{_sbindir}/sshd
%attr(0755,root,root) %{_libexecdir}/openssh/sftp-server
%attr(0644,root,root) %{_mandir}/man5/sshd_config.5*
%attr(0644,root,root) %{_mandir}/man5/moduli.5*
%attr(0644,root,root) %{_mandir}/man8/sshd.8*
%attr(0644,root,root) %{_mandir}/man8/sftp-server.8*
%attr(0600,root,root) %config(noreplace) %{_sysconfdir}/ssh/sshd_config
%attr(0644,root,root) %config(noreplace) /etc/pam.d/sshd
%attr(0755,root,root) /etc/init.d/sshd
%endif

%changelog
* Mon Aug 24 2009 Masahiro Takahata <takahata@momonga-linux.org>
- (5.2p1-3m)
- enable openssh-lpk-5.2p1-0.3.10.patch

* Tue Apr 07 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (5.2p1-2m)
- rebuild against openssl-0.9.8k

* Wed Feb 25 2009 TABUCHI Takaaki <tab@momonga-linux.org>
- (5.2p1-1m)
- [SECURITY] http://www.openssh.com/txt/cbc.adv
- update to 5.2p1
- update Patch0: openssh-5.2p1-redhat.patch
- update Patch4: openssh-5.2p1-vendor.patch
- update Patch12: openssh-5.2p1-selinux.patch
- update Patch51: openssh-5.2p1-nss-keys.patch
- comment out Patch63: openssh-5.1p1-bannerlen.patch

* Wed Jan 21 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (5.1p1-4m)
- rebuild against rpm-4.6

* Fri Sep 19 2008 Ichiro Nakai <ichiro@n.email.ne.jp>
- (5.1p1-3m)
- Obsoletes: openssh-keysign

* Fri Sep 19 2008 Masahiro Takahata <takahata@momonga-linux.org>
- (5.1p1-2m)
- sync Fedora
- base openssh-5.1p1-2.fc9

* Tue Jul 22 2008 NARITA Koichi <pulsar@momonga-linux.org>
- (5.1p1-1m)
- [SECURITY] fix vulnerability to the X11UseLocalhost=no hijacking attack
- update to 5.1p1

* Tue Jun  3 2008 NARITA Koichi <pulsar@momonga-linux.org>
- (5.0p1-3m)
- rebuild against openssl-0.9.8h-1m

* Wed Apr 16 2008 Mitsuru Shimamura <smbd@momonga-linux.org>
- (5.0p1-2m)
- use condrestart instead of restart in %post script

* Fri Apr  4 2008 TABUCHI Takaaki <tab@momonga-linux.org>
- (5.0p1-1m)
- update to 5.0

* Thu Apr 03 2008 TABUCHI Takaaki <tab@momonga-linux.org>
- (4.9p1-2m)
- rebuild against gcc43

* Mon Mar 31 2008 TABUCHI Takaaki <tab@momonga-linux.org>
- (4.9p1-1m)
- update to 4.9

* Wed Feb 13 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (4.7p1-4m)
- %%NoSource -> NoSource

* Fri Oct 26 2007 NARITA Koichi <pulsar@momonga-linux.org>
- (4.7p1-3m)
- rebuild against openssl-0.9.8g

* Sat Oct 13 2007 Ichiro Nakai <ichiro@n.email.ne.jp>
- (4.7p1-2m)
- rebuild against openssl-0.9.8f

* Fri Sep  7 2007 TABUCHI Takaaki <tab@momonga-linux.org>
- (4.7p1-1m)
- update to 4.7p1
- [SECURITY] Security bugs resolved in this release:
  * Prevent ssh(1) from using a trusted X11 cookie if creation of an
    untrusted cookie fails; found and fixed by Jan Pechanec.

* Mon Jun 18 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (4.6p1-2m)
- rebuild against pam-0.99.7-1m
- Patch: openssh-4.2p1-pam-no-stack.patch copied from fc devel

* Fri Mar  9 2007 TABUCHI Takaaki <tab@momonga-linux.org>
- (4.6p1-1m)
- update to 4.6p1

* Wed Nov 08 2006 TABUCHI Takaaki <tab@momonga-linux.org>
- (4.5p1-1m)
- update to 4.5p1

* Sat Sep 30 2006 Ryu SASAOKA <ryu@momonga-linux.org>
- (4.4p1-1m)
- update to 4.4p1
- [SECURITY] CVE-2006-4924
- http://www.openssh.com/txt/release-4.4

* Tue Mar 21 2006 Masahiro Takahata <takahata@momonga-linux.org>
- (4.3p2-2m)
- rebuild against openssl-0.9.8a

* Mon Feb 13 2006 Ryu SASAOKA <ryu@momonga-linux.org>
- (4.3p2-1m)
- update to 4.3p2

* Thu Feb 02 2006 KAJIWARA, Atsushi <kajiwara@noguard.org>
- (4.3p1-1m)
- update to 4.3

* Thu Jan 26 2006 Mitsuru Shimamura <smbd@momonga-linux.org>
- (4.2p1-2m)
- [SECURITY] CVE-2006-0225

* Fri Sep 02 2005 TABUCHI Takaaki <tab@momonga-linux.org>
- (4.2p1-1m)
- update to 4.2

* Mon Aug  8 2005 Mitsuru Shimamura <smbd@momonga-linux.org>
- (4.1p1-2m)
- ChallengeResponseAuthentication no

* Thu May 26 2005 TABUCHI Takaaki <tab@momonga-linux.org>
- (4.1p1-1m)
- update to 4.1

* Thu Mar 10 2005 TABUCHI Takaaki <tab@momonga-linux.org>
- (4.0p1-1m)
- update to 4.0

* Sun Jan 23 2005 Masahiro Takahata <takahata@momonga-linux.org>
- (3.9p1-4m)
- noinitlog for initscripts

* Sun Nov 21 2004 Masaru SANUKI <sanuki@momonga-linux.org>
- (3.9p1-3m)
- sunmaso ... (2m ni sashimodoshi)  m(_"_)m
- #"

* Sun Nov 21 2004 Masaru SANUKI <sanuki@momonga-linux.org>
- (3.9p1-3m)
- modify man directory

* Mon Aug 23 2004 YAMAZAKI Makoto <zaki@zakky.org>
- (3.9p1-2m)
- added -u0 to sshd option (in /etc/sysconfig/sshd) to suppress DNS request
- changed attribute of /etc/sysconfig/sshd to noreplace

* Thu Aug 19 2004 TABUCHI Takaaki <tab@momonga-linux.org>
- (3.9p1-1m)
- update to 3.9

* Thu Jul 29 2004 Masahiro Takahata <takahata@momonga-linux.org>
- (3.8.1pl-3m)
- modify spec

* Wed Jul 21 2004 Masahiro Takahata <takahata@momonga-linux.org>
- (3.8.1p1-2m)
- modify uid/gid

* Sat Apr 24 2004 Kazuhiko <kazuhiko@fdiary.net>
- (3.8.1p1-1m)
- minor bugfixes

* Wed Mar 31 2004 Kazuhiko <kazuhiko@fdiary.net>
- (3.8p1-1m)
- revise sshd_config.patch

* Tue Mar 30 2004 Kazuhiko <kazuhiko@fdiary.net>
- (3.8p1-1m)
- this version features many improvements and bugfixes

* Thu Mar 25 2004 Toru Hoshina <t@momonga-linux.org>
- (3.7.1p2-2m)
- revised spec for rpm 4.2.

* Wed Sep 24 2003 Kazuhiko <kazuhiko@fdiary.net>
- (3.7.1p2-1m)
- security fixes again

* Wed Sep 17 2003 Kazuhiko <kazuhiko@fdiary.net>
- (3.7.1p1-1m)
- security fixes

* Wed Apr 30 2003 HOSONO Hidetomo <h12o@h12o.org>
- (3.6.1p2-1m)

* Mon Apr  7 2003 Yuya Yamaguchi <bebe@hepo.jp>
- (3.6.1p1-1m)
- update to 3.6.1

* Tue Apr  1 2003 HOSONO Hidetomo <h13o@h12o.org>
- (3.6p1-1m)

* Wed Mar  5 2003 Tsutomu Yasuda <tom@tom.homelinux.org>
- (3.5p1-5m)
  rebuild against openssl-0.9.7a

* Thu Feb 27 2003 Masahiro Takahata <takahata@momonga-linux.org>
- (3.5p1-4m)
- openssh-askpass and openssh-askpass-gnome are separated from 
  openssh base package.

* Wed Dec 25 2002 TABUCHI Takaaki <tab@momonga-linux.org>
- (3.5p1-3m)
- change URI of x11-ssh-askpass tar ball (thanks to NARITA Koichi [Momonga-devel.ja:01144])
- delete comment lines
- always include all files(by zaki)

* Sat Dec  7 2002 HOSONO Hidetomo <h12o@h12o.org>
- (3.5p1-2m)
- rebuild against openssl-0.9.6h
- remove unnecessary comment
- correct a misspelled comment :-)

* Sun Oct 20 2002 TABUCHI Takaaki <tab@momonga-linux.org>
- (3.5p1-1m)
- update to 3.5p1
- port gnome-ssh-askpass[12] from contrib/redhat/openssh.spec
  cf. RedHat: Use contrib/ Makefile for building askpass programs
- change default gtk2 1
- change ssh-agent from attr(0755,root,root) to attr(2755,root,nobody)
  cf. RedHat: Install ssh-agent setgid nobody to prevent ptrace() key theft attacks
- change BuildPreReq gnome-libs-devel to pkgconfig

* Fri Sep 20 2002 KOMATSU Shinichiro <koma2@jiro.c.u-tokyo.ac.jp>
- (3.4p1-5m)
- add portable version to Version:
- %%no_x11_askpass and %%no_gnome_askpass can now be defined
  by command line arguments.
- add %%{?include_specopt}
- rsh support was deprecated, so remove BuildPrereq: rsh
- add ssh_config(5) man page
- add ssh-keysign sub package.
  since ssh-keysign(8) is a setuid programm and only needed
  during hostbased authentication with protocol version 2,
  installing it is not recommened.

* Thu Aug  1 2002 HOSONO Hidetomo <h@h12o.org>
- (3.4-4m)
- correct some wrong spelling of trojan(ed)

* Thu Aug  1 2002 HOSONO Hidetomo <h@h12o.org>
- (3.4-3m)
- stop building in %prep when trojaned openssh-3.4p1.tar.gz is find

* Tue Jun 27 2002 Masahiro Takahata <takahata@mtaka.com>
- (3.4-2k)
- upgrade to 3.4

* Thu Jun 25 2002 Junichiro Kita <kita@kitaj.no-ip.com>
- (3.3-4k)
- specify package name for papre and postun
- add sshd_config.5

* Thu Jun 25 2002 Junichiro Kita <kita@kitaj.no-ip.com>
- (3.3-2k)
- update to 3.3p1
- useradd/groupadd sshd for privilege separation

* Thu May 23 2002 Tsutomu Yasuda <tom@kondara.org>
- (3.2.3-2k)
  update to 3.2.3p1

* Fri May 17 2002 YAMAZAKI Makoto <zaki@kondara.org>
- (3.2.2p1-6k)
- add --with-4in6=yes configure option if _ipv6 is defined as 1

* Fri May 17 2002 HOSONO Hidetomo <h@kondara.org>
- (3.2.2p1-4k)
- change Prereq and BuildPreReq(openssl-0.9.6c or later).

* Fri May 17 2002 WATABE Toyokazu <toy2@kondara.org>
- (3.2.2p1-2k)
- update to 3.2.2p1 to fix several security ploblems.
  see http://marc.theaimsgroup.com/?l=openssh-unix-dev&m=102158874317836&w=2
- move scp to openssh package.

* Wed May  1 2002 WATABE Toyokazu <toy2@kondara.org>
- (3.1p1-6k)
- apply a patch.
  see http://marc.theaimsgroup.com/?l=openssh-unix-dev&m=101982330707988&w=2

* Fri Apr 12 2002 Yasuhiro Takabayashi <kourin@kondara.org>
- (3.1p1-4k)
- fix spec about rsa1 problem.

* Fri Mar  8 2002 Tsutomu Yasuda <tom@kondara.org>
- (3.1p1-2k)
- update to 3.1p1

* Tue Feb 19 2002 Shingo Akagaki <dora@Kondara.org>
- (3.0.2p1-8k)
- Obsoletes: sftp

* Sun Feb 17 2002 WATABE Toyokazu <toy2@kondara.org>
- (3.0.2p1-6k)
- be available sftp and its manual.

* Sun Dec  9 2001 Toru Hoshina <t@kondara.org>
- (3.0.2p1-4k)
- applied init patch.
- See. [Kondara-devel.ja:06055]

* Tue Dec  4 2001 Toru Hoshina <t@kondara.org>
- (3.0.2p1-2k)
- update to 3.0.2p1
- suma-so.

* Tue Nov 20 2001 Tsutomu Yasuda <tom@kondara.org>
- (3.0.1p1-2k)
  update to 3.0.1p1

* Mon Nov 12 2001 Tsutomu Yasuda <tom@kondara.org>
- (3.0p1-2k)
  update to 3.0p1

* Thu Oct 18 2001 Toru Hoshina <t@kondara.org>
- (2.9.9p2-4k)
- rebuild against gettext 0.10.40.

* Sun Sep 30 2001 MATSUDA< Daiki <dyky@df-usa.com>
- (2.9.9p2-2k)
- update to 2.9.9p2 for security fix (http://www.securityfocus.com/bid/3369)
- update x11-ask-pass to 1.2.4.1
- rename /etc/ssh/primes to /etc/ssh/moduli for fixing original source

* Mon Sep 24 2001 Toru Hoshina <t@kondara.org>
- (2.9p2-16k)
- suid of /usr/bin/ssh is turned off.
- scp should be in ssh-clients.

* Fri Sep 21 2001 Tsutomu Yasuda <tom@digitalfactory.co.jp>
- (2.9p2-14k)
  fix spec

* Sun Sep  9 2001 Toru Hoshina <t@kondara.org>
- (2.9p2-8k)
- rebuild against XFree 4.1.0, applied x11-askpass-1.2.2-xf41.patch, however
  it might be wrong for X403 environment.

* Tue Aug  7 2001 Toru Hoshina <toru@df-usa.com>
- (2.9p2-6k)
- add alphaev5 support.

* Sun Jul 16 2001 MATSUDA, Daiki <dyky@df-usa.com>
- (2.9p2-4k)
- update to 2.9p2 for openssl security fix
- so, modified add version '0.9.6b' to openssl required tag

* Fri Jun 22 2001 KOMATSU Shinichiro <koma2@jiro.c.u-tokyo.ac.jp>
- (2.9p2-3k)
- update to 2.9p2
- delete openssh-2.9-cookies.patch 
  since it is already imported into source

* Sat Jun 16 2001 KOMATSU Shinichiro <koma2@jiro.c.u-tokyo.ac.jp>
- (2.9p1-9k)
- added openssh-2.9-cookies.patch (from FreeBSD's openssh-portable port)
  this patch fixed the problem of
  http://www.securityfocus.com/archive/1/188450
- BuildPreReq: pam => pam-devel

* Thu May  3 2001 Tsutomu Yasuda <tom@digitalfactory.co.jp>                     
- (2.9p1-4k)
  added %{_sysconfdir}/sysconfig/sshd

* Thu May  3 2001 Tsutomu Yasuda <tom@digitalfactory.co.jp>                     
- (2.9p1-2k)                                                                    
  openssh update to 2.9p1                                                       
  x11-askpass update to 1.2.2

* Thu Apr 19 2001 Kenichi Matsubara <m@kondara.org>
- (2.5.2p2-10k)
- remove sftp,sftp.man.

* Sat Apr 14 2001 Toru Hoshina <toru@df-usa.com>
- (2.5.2p2-8k)
- rebuild against openssl 0.9.6.

* Sat Mar 24 2001 KOMATSU Shinichiro <koma2@jiro.c.u-tokyo.ac.jp>
- (2.5.2p2-3k)
- update to 2.5.2p2

* Thu Mar 22 2001 Toru Hoshina <toru@df-usa.com>
- (2.5.2p1-7k)
- support gtk+1-1.2.9

* Thu Mar 22 2001 KOMATSU Shinichiro <koma2@jiro.c.u-tokyo.ac.jp>
- (2.5.2p1-5k)
- when creating ssh_host_dsa_key, use "-t dsa" instead of "-d".
- create ssh_host_rsa_key (RSA key for protocol ver.2) on %%post.
- uncommentout "HostKey /etc/ssh/ssh_host_rsa_key"

* Wed Mar 20 2001 TABUCHI Takaaki <tab@kondara.org>
- (2.5.2p1-3k)
- update to 2.5.2p1
- change openssh-kondara.patch adapt for openssh-2.5.2p1.
  (and comment out "HostKey /etc/ssh/ssh_host_rsa_key".
   If you want to use this function, maybe you need to 
   add exec ssh-keygen at post server section in this spec file.)
- comment out make-ssh-known-hosts at install,
  because this file is deleted in openssh tarball.
  (This file is not listed in files section. miss?)
- add ssh-copy-id, ssh-copy-id.1* in clients files section

* Thu Mar  1 2001 KOMATSU Shinichiro <koma2@jiro.c.u-tokyo.ac.jp>
- (2.5.1p2-3k)
- update to 2.5.1p2

* Wed Feb 28 2001 TABUCHI Takaaki <tab@kondara.org>
- (2.5.1p1-5k)
- add --with-pam at configure
- comment out ssh-keyscan* at files for clients package

* Mon Feb 23 2001 TABUCHI Takaaki <tab@kondara.org>
- (2.5.1p1-3k)
- update to 2.5.1p1
- comment out patch1(openssh-init.patch)
- remove README.Ylonen, COPYING.Ylonen
- update x11-ssh-askpass for 1.2.0
- add /etc/ssh/primes at files
- fix missed directory /etc/ssh/primes
- change permission 600 to 644 /etc/pam.d/sshd

* Mon Feb 05 2001 WATABE Toyokazu <toy2@kondara.org>
- (2.3.0p1-13k)
- use _sysconfdir macro.
- add make-ssh-known-hosts and ssh-copy-id.
* Sat Feb  3 2001 MATSUDA, Daiki <dyky@df-usa.com>
- (2.3.0p1-11k)
- rebuild againt rpm-3.0.5-39k
* Tue Nov 28 2000 Toru Hoshina <toru@df-usa.com>
- (2.3.0p1-7k)
- use _initscriptdir macro to keep backword compatibility.
* Thu Nov 16 2000 Toyokazu WATABE <toy2@kondara.org>
- (2.3.0p1-5k)
- update gnome-ssh-askpass.* made by h@kondara.org.
* Wed Nov 15 2000 Toyokazu WATABE <toy2@kondara.org>
- (2.3.0p1-3k)
- update x11-ssh-askpass for 1.1.1
- modified install of x11-ssh-askpass.
* Tue Nov 07 2000 Toyokazu WATABE <toy2@kondara.org>
- (2.3.0p1-2k)
- update x11-ssh-askpass for 1.1.0
- add openssh-init.patch
* Tue Nov 07 2000 Toyokazu WATABE <toy2@kondara.org>
- (2.3.0p1-1k)
- update openssh for 2.3.0p1
- update openssh-kondara.patch
- remove sshd.init
* Mon Oct 30 2000 Toyokazu WATABE <toy2@kondara.org>
- (2.2.0p1-4k)
- update ssh-askpass for 1.0.3
* Mon Oct 16 2000 Toyokazu WATABE <toy2@kondara.org>
- (2.2.0p1-2k)
- update ssh-askpass for 1.0.2
* Fri Sep 15 2000 Toyokazu WATABE <toy2@kondara.org>
- (2.2.0p1-1k)
- Adopt to FHS-2.1
* Sat Sep 02 2000 Toyokazu WATABE <toy2@kondara.org>
- (2.2.0p1-0k)
- add openssh-2.2.0p1-kondara.patch
* Tue Aug 08 2000 Damien Miller <djm@mindrot.org>
- Some surgery to sshd.init (generate keys at runtime)
- Cleanup of groups and removal of keygen calls
* Wed Jul 12 2000 Damien Miller <djm@mindrot.org>
- Make building of X11-askpass and gnome-askpass optional
* Thu Jun 15 2000 Toyokazu Watabe <toy2@kondara.org>
- add openssh-2.1.1p1-kondara.patch
  fix config files and these pathes.
* Mon Jun 12 2000 Damien Miller <djm@mindrot.org>
- Glob manpages to catch compressed files
* Sat Jun 10 2000 Toyokazu Watabe <toy2@kondara.org>
- update for 2.1.1p1
* Mon May 29 2000 Hidetomo Hosono <h@kondara.org>
- patched for contrib/gnome-ssh-askpass.c
  because of the problem with grabbing X server and command arguments dealing.
  (very quick and ad-hoc hack)
* Wed May 10 2000 Toyokazu Watabe <toy2@kondara.org>
- update for 2.1.0
* Sun Mar 26 2000 Tenkou N. Hattori <tnh@kondara.org>
- be a NoSrc :-P
* Wed Mar 15 2000 Damien Miller <djm@ibs.com.au>
- Updated for new location
- Updated for new gnome-ssh-askpass build
* Sun Dec 26 1999 Damien Miller <djm@mindrot.org>
- Added Jim Knoble's <jmknoble@pobox.com> askpass
* Mon Nov 15 1999 Damien Miller <djm@mindrot.org>
- Split subpackages further based on patch from jim knoble <jmknoble@pobox.com>
* Sat Nov 13 1999 Damien Miller <djm@mindrot.org>
- Added 'Obsoletes' directives
* Tue Nov 09 1999 Damien Miller <djm@ibs.com.au>
- Use make install
- Subpackages
* Mon Nov 08 1999 Damien Miller <djm@ibs.com.au>
- Added links for slogin
- Fixed perms on manpages
* Sat Oct 30 1999 Damien Miller <djm@ibs.com.au>
- Renamed init script
* Fri Oct 29 1999 Damien Miller <djm@ibs.com.au>
- Back to old binary names
* Thu Oct 28 1999 Damien Miller <djm@ibs.com.au>
- Use autoconf
- New binary names
* Wed Oct 27 1999 Damien Miller <djm@ibs.com.au>
- Initial RPMification, based on Jan "Yenya" Kasprzak's <kas@fi.muni.cz> spec.
